@@ -1,5 +1,3 @@
-from collections import deque
-
 from bestia.output import Row, FString, echo
 
 from .degrees import *
@@ -7,8 +5,8 @@ from .notes import *
 
 class TonalKey(object):
 
-    def __init__(self, c, alt='', oct=0):
-        self.root = Note(c, alt, 0) # ignore note.oct
+    def __init__(self, chr, alt='', oct=0):
+        self.root = Note(chr, alt, 0) # ignore note.oct
 
     def __repr__(self):
         spell_line = Row()
@@ -23,6 +21,9 @@ class TonalKey(object):
     def __getitem__(self, i):
         return self.degree(i)
 
+    @property
+    def name(self):
+        return self.__class__.__name__
 
     @classmethod
     def __possible_root_notes(cls, valids=True):
@@ -462,3 +463,59 @@ class ChromaticKey(TonalKey):
             return Note(deg.chr, deg.alt, deg_oct)
 
         raise InvalidNote
+
+TONAL_CLASSES = {
+
+    'major': MajorKey,
+
+    'minor': MinorKey,
+    'natural_minor': NaturalMinorKey,
+    'melodic_minor': MelodicMinorKey,
+    'harmonic_minor': HarmonicMinorKey,
+
+    'ionian': IonianMode,
+    'lydian': LydianMode,
+    'mixo': MixolydianMode,
+    'aeolian': AeolianMode,
+    'dorian': DorianMode,
+    'phrygian': PhrygianMode,
+
+    # 'hokkaido': Hokkaido,
+
+    'chromatic': ChromaticKey,
+
+}
+
+# CHORDS = {
+#     # TRIADS ########################
+#     '': MajorTriadChord,
+#     'M': MajorTriadChord,
+
+#     'm': MinorTriadChord,
+
+#     'a': AugmentedTriadChord,
+    #  '+': AugmentedTriadChord,
+
+#     'd': DiminishedTriadChord,
+#     '-': DiminishedTriadChord,
+
+#     # SEVENTH #######################
+#     '7': DominantSeventhChord,
+#     'dom7': DominantSeventhChord,
+
+#     'M7': MajorSeventhChord,
+#     'maj7': MajorSeventhChord,
+#     '△7': MajorSeventhChord,
+
+#     'm7': MinorSeventhChord,
+#     'min7': MinorSeventhChord,
+    
+#     'D7': DiminishedSeventhChord,
+#     'dim7': DiminishedSeventhChord,
+#     '°7': DiminishedSeventhChord,
+
+#     'd7': HalfDiminishedSeventhChord, # isnt this one usually used for diminished (instead of D7)?
+#     'm7-5': HalfDiminishedSeventhChord,
+#     '⦰7': HalfDiminishedSeventhChord,
+
+# }
